import _extends from "@babel/runtime/helpers/esm/extends";
import { generate } from '@ant-design/colors';
import { TinyColor } from '@ctrl/tinycolor';
import { defaultPresetColors } from '../seed';
import genColorMapToken from '../shared/genColorMapToken';
import genCommonMapToken from '../shared/genCommonMapToken';
import { generateBgPalettes, generateErrorPalettes, generateInfoPalettes, generatePrimaryPalettes, generateSuccessPalettes, generateTextAlphaPalettes, generateWarningPalettes } from './palettes';
export default function derivative(token) {
  var colorSuccess = token.colorSuccess,
      colorWarning = token.colorWarning,
      colorError = token.colorError,
      colorInfo = token.colorInfo;
  var colorPalettes = Object.keys(defaultPresetColors).map(function (colorKey) {
    var colors = generate(token[colorKey], {
      theme: 'dark'
    });
    return new Array(10).fill(1).reduce(function (prev, _, i) {
      prev["".concat(colorKey, "-").concat(i + 1)] = colors[i];
      return prev;
    }, {});
  }).reduce(function (prev, cur) {
    prev = _extends(_extends({}, prev), cur);
    return prev;
  }, {});
  var colorPrimary = token.colorPrimary || '#177ddc';
  var colorBgBase = token.colorBgBase || '#000';
  var colorTextBase = token.colorTextBase || '#fff';
  var primaryColors = generatePrimaryPalettes(colorPrimary);
  var successColors = generateSuccessPalettes(colorSuccess);
  var warningColors = generateWarningPalettes(colorWarning);
  var errorColors = generateErrorPalettes(colorError);
  var infoColors = generateInfoPalettes(colorInfo);
  var bgColors = generateBgPalettes(colorBgBase);
  var textColors = generateTextAlphaPalettes(colorTextBase);
  return _extends(_extends(_extends(_extends(_extends(_extends({}, token), colorPalettes), {
    colorPrimary: colorPrimary
  }), genColorMapToken({
    primaryPalettes: primaryColors,
    successPalettes: successColors,
    warningPalettes: warningColors,
    errorPalettes: errorColors,
    infoPalettes: infoColors,
    bgPalettes: bgColors,
    textAlphaPalettes: textColors
  })), {
    colorPrimaryOutline: new TinyColor(colorPrimary).setAlpha(0.2).toRgbString(),
    colorErrorOutline: new TinyColor(colorError).setAlpha(0.2).toRgbString(),
    colorWarningOutline: new TinyColor(colorWarning).setAlpha(0.2).toRgbString()
  }), genCommonMapToken(token));
}